'-----------------------------------------------------------------------------------
' JustLDAP script for bulk importing users into a ***Remote*** Active Directory from
' an MS Access database .
' 
' Demonstrates standard text error message retrieval to assist debugging.
' Input is an Access 2000 Jet 4.0 database file in the same directory as this script. 
'
'-----------------------------------------------------------------------------------
Option Explicit

Dim oLdap, Result, FileName, First, Last, Login, EmployeeID, Ctr
Dim ConnString, usercommonname
Dim conection ' ADO connection
Dim RecordSet ' ADO recordset

'-------- Open the database file and read the records.

Wscript.Echo("Begin Import")

Ctr=0

FileName = "userdata.mdb"
Set conection = CreateObject("ADODB.Connection")
Set oLdap = CreateObject("JustLDAPDomain.DomainAdmin")

ConnString = "Provider=Microsoft.Jet.OLEDB.4.0;Data Source=" & FileName

conection.Open ConnString

' Select all rows in the 'UserDetails' table.
Set RecordSet = conection.Execute("SELECT * FROM UserDetails")

' Now simply loop through each user 'row' and create them in the standard "Users"
' container of your Active Directory. 
' Add some properties like employeeID to the Active Directory user database.
' Just modify this script to suit the properties you wish to import/set for each user.
 
 
Do While Not RecordSet.EOF
  ' Trim the fields in case there are leading or trailing spaces.

  First = Trim(RecordSet.Fields("FirstName").Value)
  Last = Trim(RecordSet.Fields("LastName").Value)
  Login = Trim(RecordSet.Fields("LoginID").Value)
  EmployeeID = Trim(RecordSet.Fields("employeeID").Value)

  usercommonname = First + " " + Last

  ' All users are assigned the same password initialy
  Result = oLdap.CreateUserDom(Login, usercommonname, "initialp@ssword1", "otherdomain.com", "admin42", "secretpw55$") 

  If oLdap.ErrorOccurred() = True Then
    Result = oLdap.GetLastErrorAsMessage()
    Wscript.Echo Result
    Set oLdap = Nothing
    Wscript.Quit
  End If

  Result = oLdap.SetUserPropertyDom(Login, "givenName", First, "otherdomain.com", "admin42", "secretpw55$")
  If oLdap.ErrorOccurred() = True Then
    Result = oLdap.GetLastErrorAsMessage()
    Wscript.Echo Result
    Set oLdap = Nothing
    Wscript.Quit
  End If
  
  Result = oLdap.SetUserPropertyDom(Login, "sn", Last, "otherdomain.com", "admin42", "secretpw55$")
  If oLdap.ErrorOccurred() = True Then
    Result = oLdap.GetLastErrorAsMessage()
    Wscript.Echo Result
    Set oLdap = Nothing
    Wscript.Quit
  End If

  Result = oLdap.SetUserPropertyDom(Login, "userPrincipalName", Login & "@otherdomain.com", "otherdomain.com", "admin42", "secretpw55$")
  If oLdap.ErrorOccurred() = True Then
    Result = oLdap.GetLastErrorAsMessage()
    Wscript.Echo Result
    Set oLdap = Nothing
    Wscript.Quit
  End If

  Result = oLdap.SetUserPropertyDom(Login, "employeeID", EmployeeID, "otherdomain.com", "admin42", "secretpw55$")
  If oLdap.ErrorOccurred() = True Then
    Result = oLdap.GetLastErrorAsMessage()
    Wscript.Echo Result
    Set oLdap = Nothing
    Wscript.Quit
  End If

  ' Use JustLDAP account control to force the user to change the default password 

  Result = oLdap.UserMustChangePasswordAtNextLogonDom(Login, True, "otherdomain.com", "admin42", "secretpw55$")
  If oLdap.ErrorOccurred() = True Then
    Result = oLdap.GetLastErrorAsMessage()
    Wscript.Echo Result
    Set oLdap = Nothing
    Wscript.Quit
  End If
 
 
  RecordSet.MoveNext ' Loop back and read in the next account to create.
  
  Ctr = Ctr + 1 ' Count the records completed
  Wscript.Echo(Ctr)
Loop
 
RecordSet.Close
Set RecordSet = Nothing
conection.Close
Set conection = Nothing
Set oLdap = Nothing

Wscript.Echo("Done")

